@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+"""Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,13 +30,13 @@ from tile import Tile, TileList
 from tilesource import TileSource
 from meld import Meld, MeldList
 from rule import Score, UsedRule
-from common import Debug, isPython3
+from common import Debug, StrMixin
 from intelligence import AIDefault
 from util import callers
 from message import Message
 
 
-class Hand(object):
+class Hand(StrMixin):
 
     """represent the hand to be evaluated.
 
@@ -124,8 +124,7 @@ class Hand(object):
             self.debug(fmt('{callers}',
                            callers=callers(exclude=['__init__'])))
             Hand.indent += 1
-            _hideString = string
-            self.debug(fmt('New Hand {_hideString} {self.lenOffset}'))
+            self.debug('New Hand {} {}'.format(string, self.lenOffset))
 
         try:
             self.__arrange()
@@ -139,10 +138,7 @@ class Hand(object):
         finally:
             self._fixed = True
             if Debug.hand or (Debug.mahJongg and self.lenOffset == 1):
-                _hideSelf = str(self)
-                _hideScore = str(self.score)
-                self.debug(fmt(
-                    'Fixing {_hideSelf} {self.won} {_hideScore}'))
+                self.debug('Fixing {} {} {}'.format(self, self.won, self.score))
             Hand.indent -= 1
 
     def __parseString(self, inString):
@@ -527,7 +523,7 @@ class Hand(object):
             if Debug.hand and cand:
                 # Py2 and Py3 show sets differently
                 candis = ''.join(str(x) for x in sorted(cand)) # pylint: disable=unused-variable
-                self.debug(fmt('callingHands found {candis} for {rule}'))
+                self.debug('callingHands found {} for {}'.format(candis, rule))
             candidates.extend(x.concealed for x in cand)
         for tile in sorted(set(candidates)):
             if sum(x.exposed == tile.exposed for x in self.tiles) == 4:
@@ -761,32 +757,16 @@ class Hand(object):
         """hand as a string"""
         return self.newString()
 
-    def __unicode__(self):
-        """hand as a string"""
-        return self.newString()
-
-    def __repr__(self):
-        """the default representation"""
-        return 'Hand(%s)' % str(self)
-
     def __hash__(self):
         """used for debug logging to identify the hand"""
         if not hasattr(self, 'string'):
             return 0
         md5sum = md5()
-        if isPython3:
-            md5sum.update(self.player.name.encode('utf-8'))
-            md5sum.update(self.string.encode())
-        else:
-            md5sum.update(self.player.name.encode('utf-8'))
-            md5sum.update(self.string)
+        md5sum.update(self.player.name.encode('utf-8'))
+        md5sum.update(self.string.encode())
         digest = md5sum.digest()
         assert len(digest) == 16
         result = 0
-        if isPython3:
-            for part in range(4):
-                result = (result << 8) + digest[part]
-        else:
-            for part in range(4):
-                result = (result << 8) + ord(digest[part])
+        for part in range(4):
+            result = (result << 8) + digest[part]
         return result
